InviteFailureEvent class

Event emitted when a call fails.

Inheritance

Constructors

InviteFailureEvent(int sessionId, String reason, int code)

Properties

code → int
Error code
final
data → Map<String, dynamic>?
Optional data associated with the event
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the event (e.g., "onRegisterSuccess", "onInviteConnected")
finalinherited
reason → String
Reason for the failure
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → int
The session ID of the call
final
timestamp → DateTime
Timestamp when the event was created
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited