dispose method
Disposes of all SDK resources and cleans up.
This method should be called when the plugin is no longer needed, typically when the app is shutting down.
This method:
- Unregisters from the SIP server
- Removes all observers and listeners
- Releases native SDK resources
- Clears event stream handlers
After calling dispose(), the plugin instance should not be used. To swap SIP users at runtime use unInitialize instead.
Implementation
Future<void> dispose() async {
throw UnimplementedError('dispose has not been implemented.');
}